// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;

namespace DsPdfWeb.Demos.Basics
{
    // 通常のフォントを使用するときに太字または斜体のエミュレーションを制御する方法を示します。
    public class BoldItalicEmulation
    {
        public int CreatePDF(Stream stream)
        {
            var fc = new FontCollection();
            fc.RegisterDirectory(Path.Combine("Resources", "Fonts"));
            var doc = new GcPdfDocument();
            var g = doc.NewPage().Graphics;
            var rc = Common.Util.AddNote(
                "TextFormat.FontStyleでは、太字または斜体のフォントを適用するのではなく、" +
                "太字または斜体のエミュレーションを有効にすることができます。", doc.Pages.Last);
            // テキストの挿入位置。
            var ip = new PointF(rc.Left, rc.Bottom + 36);
            var tf = new TextFormat();
            // 非太字/非斜体のフォントを取得します。
            tf.Font = fc.FindFamilyName("Times New Roman", false, false);
            tf.FontSize = 16;
            g.DrawString($"通常のフォント: {tf.Font.FullFontName}", tf, ip);
            ip.Y += 36;
            // 同じ（標準の）フォントを使用して、太字と斜体をエミュレートした文字列を描画します。
            tf.FontStyle = GCTEXT.FontStyle.Bold;
            g.DrawString($"太字をエミュレーション: {tf.Font.FullFontName}", tf, ip);
            ip.Y += 36;
            tf.FontStyle = GCTEXT.FontStyle.Italic;
            g.DrawString($"斜体をエミュレーション: {tf.Font.FullFontName}", tf, ip);
            ip.Y += 36;
            tf.FontStyle = GCTEXT.FontStyle.BoldItalic;
            g.DrawString($"太字と斜体をエミュレーション: {tf.Font.FullFontName}", tf, ip);
            ip.Y += 36;
            //
            // フォントの "実際の" 太字/斜体の変種を使用して、いくつかの文字列を描画します。
            tf.FontStyle = GCTEXT.FontStyle.Regular;
            tf.Font = fc.FindFamilyName("Times New Roman", true, false);
            g.DrawString($"実際の太字フォントを適用: {tf.Font.FullFontName}", tf, ip);
            ip.Y += 36;
            tf.Font = fc.FindFamilyName("Times New Roman", false, true);
            g.DrawString($"実際のフォントで斜体を適用: {tf.Font.FullFontName}", tf, ip);
            ip.Y += 36;
            tf.Font = fc.FindFamilyName("Times New Roman", true, true);
            g.DrawString($"実際のフォントで太字を適用: {tf.Font.FullFontName}", tf, ip);
            ip.Y += 36;
            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
